---
name: Bug report
about: Create a report to help us improve!
title: "[BUG] "
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Code example**
Minimal code example to recreate the issue.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Tiler version**
Can be retrieved with `python -c "import tiler; print(tiler.__version__)"`.
